==> mteb-1.12.42.tar.gz: mteb-1.12.42/mteb/tasks/Retrieval/__init__.py <==
from __future__ import annotations

from .code.CodeEditSearchRetrieval import *
from .code.CodeSearchNetRetrieval import *
from .dan.dan_fever import *
from .dan.t2nord_retrieval import *
from .dan.twitterhjerne import *
from .deu.GerDaLIRRetrieval import *
from .deu.GerDaLIRSmallRetrieval import *
from .deu.GermanDPRRetrieval import *
from .deu.GermanGovServiceRetrieval import *
from .deu.GermanQuADRetrieval import *
from .deu.LegalQuADRetrieval import *
from .ell.GreekCivicsQA import *
from .eng.AILACasedocsRetrieval import *
from .eng.AILAStatutesRetrieval import *
from .eng.AlphaNLIRetrieval import *
from .eng.ARCChallengeRetrieval import *
from .eng.ArguAnaRetrieval import *
from .eng.ClimateFEVERRetrieval import *
from .eng.CQADupstackAndroidRetrieval import *
from .eng.CQADupstackEnglishRetrieval import *
from .eng.CQADupstackGamingRetrieval import *
from .eng.CQADupstackGisRetrieval import *
from .eng.CQADupstackMathematicaRetrieval import *
from .eng.CQADupstackPhysicsRetrieval import *
from .eng.CQADupstackProgrammersRetrieval import *
from .eng.CQADupstackStatsRetrieval import *
from .eng.CQADupstackTexRetrieval import *
from .eng.CQADupstackUnixRetrieval import *
from .eng.CQADupstackWebmastersRetrieval import *
from .eng.CQADupstackWordpressRetrieval import *
from .eng.DBPediaRetrieval import *
from .eng.FaithDialRetrieval import *
from .eng.FeedbackQARetrieval import *
from .eng.FEVERRetrieval import *
from .eng.FiQA2018Retrieval import *
from .eng.HagridRetrieval import *
from .eng.HellaSwagRetrieval import *
from .eng.HotpotQARetrieval import *
from .eng.LegalBenchConsumerContractsQARetrieval import *
from .eng.LegalBenchCorporateLobbyingRetrieval import *
from .eng.LegalSummarizationRetrieval import *
from .eng.LEMBNarrativeQARetrieval import *
from .eng.LEMBNeedleRetrieval import *
from .eng.LEMBPasskeyRetrieval import *
from .eng.LEMBQMSumRetrieval import *
from .eng.LEMBSummScreenFDRetrieval import *
from .eng.LEMBWikimQARetrieval import *
from .eng.MedicalQARetrieval import *
from .eng.MLQuestions import *
from .eng.MSMARCORetrieval import *
from .eng.MSMARCOv2Retrieval import *
from .eng.NarrativeQARetrieval import *
from .eng.NFCorpusRetrieval import *
from .eng.NQRetrieval import *
from .eng.PiqaRetrieval import *
from .eng.QuailRetrieval import *
from .eng.QuoraRetrieval import *
from .eng.RARbCodeRetrieval import *
from .eng.RARbMathRetrieval import *
from .eng.SCIDOCSRetrieval import *
from .eng.SciFactRetrieval import *
from .eng.SiqaRetrieval import *
from .eng.SpartQARetrieval import *
from .eng.TempReasonL1Retrieval import *
from .eng.TempReasonL2ContextRetrieval import *
from .eng.TempReasonL2FactRetrieval import *
from .eng.TempReasonL2PureRetrieval import *
from .eng.TempReasonL3ContextRetrieval import *
from .eng.TempReasonL3FactRetrieval import *
from .eng.TempReasonL3PureRetrieval import *
from .eng.TopiOCQARetrieval import *
from .eng.Touche2020Retrieval import *
from .eng.TRECCOVIDRetrieval import *
from .eng.WinoGrandeRetrieval import *
from .est.estqa import *
from .fra.AlloprofRetrieval import *
from .fra.BSARDRetrieval import *
from .fra.FQuADRetrieval import *
from .fra.SyntecRetrieval import *
from .hun.HunSum2 import *
from .jpn.JaGovFaqsRetrieval import *
from .jpn.JaQuADRetrieval import *
from .jpn.NLPJournalAbsIntroRetrieval import *
from .jpn.NLPJournalTitleAbsRetrieval import *
from .jpn.NLPJournalTitleIntroRetrieval import *
from .kat.GeorgianFAQRetrieval import *
from .kor.KoMiracl import *
from .kor.KoStrategyQA import *
from .multilingual.BelebeleRetrieval import *
from .multilingual.CrossLingualSemanticDiscriminationWMT19 import *
from .multilingual.CrossLingualSemanticDiscriminationWMT21 import *
from .multilingual.IndicQARetrieval import *
from .multilingual.MintakaRetrieval import *
from .multilingual.MIRACLRetrieval import *
from .multilingual.MLQARetrieval import *
from .multilingual.MultiLongDocRetrieval import *
from .multilingual.NeuCLIR2022Retrieval import *
from .multilingual.NeuCLIR2023Retrieval import *
from .multilingual.PublicHealthQARetrieval import *
from .multilingual.StatcanDialogueDatasetRetrieval import *
from .multilingual.WikipediaRetrievalMultilingual import *
from .multilingual.XMarketRetrieval import *
from .multilingual.XPQARetrieval import *
from .multilingual.XQuADRetrieval import *
from .nob.norquad import *
from .nob.snl_retrieval import *
from .pol.ArguAnaPLRetrieval import *
from .pol.DBPediaPLRetrieval import *
from .pol.FiQAPLRetrieval import *
from .pol.HotpotQAPLRetrieval import *
from .pol.MSMARCOPLRetrieval import *
from .pol.NFCorpusPLRetrieval import *
from .pol.NQPLRetrieval import *
from .pol.QuoraPLRetrieval import *
from .pol.SCIDOCSPLRetrieval import *
from .pol.SciFactPLRetrieval import *
from .pol.TRECCOVIDPLRetrieval import *
from .rus.RiaNewsRetrieval import *
from .rus.RuBQRetrieval import *
from .slk.SlovakSumRetrieval import *
from .spa.SpanishPassageRetrievalS2P import *
from .spa.SpanishPassageRetrievalS2S import *
from .swe.swedn_retrieval import *
from .swe.swefaq_retrieval import *
from .tur.TurHistQuad import *
from .vie.VieQuADRetrieval import *
from .zho.CMTEBRetrieval import *
from .zho.LeCaRDv2Retrieval import *

==> mteb-1.12.65.tar.gz: mteb-1.12.65/mteb/tasks/Retrieval/__init__.py <==
from __future__ import annotations

from .code.CodeEditSearchRetrieval import *
from .code.CodeSearchNetRetrieval import *
from .dan.DanFeverRetrieval import *
from .dan.TV2Nordretrieval import *
from .dan.TwitterHjerneRetrieval import *
from .deu.GerDaLIRRetrieval import *
from .deu.GerDaLIRSmallRetrieval import *
from .deu.GermanDPRRetrieval import *
from .deu.GermanGovServiceRetrieval import *
from .deu.GermanQuADRetrieval import *
from .deu.LegalQuADRetrieval import *
from .ell.GreekCivicsQA import *
from .eng.AILACasedocsRetrieval import *
from .eng.AILAStatutesRetrieval import *
from .eng.AlphaNLIRetrieval import *
from .eng.ARCChallengeRetrieval import *
from .eng.ArguAnaRetrieval import *
from .eng.ClimateFEVERRetrieval import *
from .eng.CQADupstackAndroidRetrieval import *
from .eng.CQADupstackEnglishRetrieval import *
from .eng.CQADupstackGamingRetrieval import *
from .eng.CQADupstackGisRetrieval import *
from .eng.CQADupstackMathematicaRetrieval import *
from .eng.CQADupstackPhysicsRetrieval import *
from .eng.CQADupstackProgrammersRetrieval import *
from .eng.CQADupstackStatsRetrieval import *
from .eng.CQADupstackTexRetrieval import *
from .eng.CQADupstackUnixRetrieval import *
from .eng.CQADupstackWebmastersRetrieval import *
from .eng.CQADupstackWordpressRetrieval import *
from .eng.DBPediaRetrieval import *
from .eng.FaithDialRetrieval import *
from .eng.FeedbackQARetrieval import *
from .eng.FEVERRetrieval import *
from .eng.FiQA2018Retrieval import *
from .eng.HagridRetrieval import *
from .eng.HellaSwagRetrieval import *
from .eng.HotpotQARetrieval import *
from .eng.LegalBenchConsumerContractsQARetrieval import *
from .eng.LegalBenchCorporateLobbyingRetrieval import *
from .eng.LegalSummarizationRetrieval import *
from .eng.LEMBNarrativeQARetrieval import *
from .eng.LEMBNeedleRetrieval import *
from .eng.LEMBPasskeyRetrieval import *
from .eng.LEMBQMSumRetrieval import *
from .eng.LEMBSummScreenFDRetrieval import *
from .eng.LEMBWikimQARetrieval import *
from .eng.MedicalQARetrieval import *
from .eng.MLQuestions import *
from .eng.MSMARCORetrieval import *
from .eng.MSMARCOv2Retrieval import *
from .eng.NarrativeQARetrieval import *
from .eng.NFCorpusRetrieval import *
from .eng.NQRetrieval import *
from .eng.PiqaRetrieval import *
from .eng.QuailRetrieval import *
from .eng.QuoraRetrieval import *
from .eng.RARbCodeRetrieval import *
from .eng.RARbMathRetrieval import *
from .eng.SCIDOCSRetrieval import *
from .eng.SciFactRetrieval import *
from .eng.SiqaRetrieval import *
from .eng.SpartQARetrieval import *
from .eng.TempReasonL1Retrieval import *
from .eng.TempReasonL2ContextRetrieval import *
from .eng.TempReasonL2FactRetrieval import *
from .eng.TempReasonL2PureRetrieval import *
from .eng.TempReasonL3ContextRetrieval import *
from .eng.TempReasonL3FactRetrieval import *
from .eng.TempReasonL3PureRetrieval import *
from .eng.TopiOCQARetrieval import *
from .eng.Touche2020Retrieval import *
from .eng.TRECCOVIDRetrieval import *
from .eng.WinoGrandeRetrieval import *
from .est.estqa import *
from .fra.AlloprofRetrieval import *
from .fra.BSARDRetrieval import *
from .fra.FQuADRetrieval import *
from .fra.SyntecRetrieval import *
from .hun.HunSum2 import *
from .jpn.JaGovFaqsRetrieval import *
from .jpn.JaQuADRetrieval import *
from .jpn.NLPJournalAbsIntroRetrieval import *
from .jpn.NLPJournalTitleAbsRetrieval import *
from .jpn.NLPJournalTitleIntroRetrieval import *
from .kat.GeorgianFAQRetrieval import *
from .kor.KoStrategyQA import *
from .multilingual.BelebeleRetrieval import *
from .multilingual.CrossLingualSemanticDiscriminationWMT19 import *
from .multilingual.CrossLingualSemanticDiscriminationWMT21 import *
from .multilingual.IndicQARetrieval import *
from .multilingual.MintakaRetrieval import *
from .multilingual.MIRACLRetrieval import *
from .multilingual.MLQARetrieval import *
from .multilingual.MultiLongDocRetrieval import *
from .multilingual.NeuCLIR2022Retrieval import *
from .multilingual.NeuCLIR2023Retrieval import *
from .multilingual.PublicHealthQARetrieval import *
from .multilingual.StatcanDialogueDatasetRetrieval import *
from .multilingual.WikipediaRetrievalMultilingual import *
from .multilingual.XMarketRetrieval import *
from .multilingual.XPQARetrieval import *
from .multilingual.XQuADRetrieval import *
from .nob.norquad import *
from .nob.snl_retrieval import *
from .pol.ArguAnaPLRetrieval import *
from .pol.DBPediaPLRetrieval import *
from .pol.FiQAPLRetrieval import *
from .pol.HotpotQAPLRetrieval import *
from .pol.MSMARCOPLRetrieval import *
from .pol.NFCorpusPLRetrieval import *
from .pol.NQPLRetrieval import *
from .pol.QuoraPLRetrieval import *
from .pol.SCIDOCSPLRetrieval import *
from .pol.SciFactPLRetrieval import *
from .pol.TRECCOVIDPLRetrieval import *
from .rus.RiaNewsRetrieval import *
from .rus.RuBQRetrieval import *
from .slk.SlovakSumRetrieval import *
from .spa.SpanishPassageRetrievalS2P import *
from .spa.SpanishPassageRetrievalS2S import *
from .swe.SwednRetrieval import *
from .swe.SweFaqRetrieval import *
from .tur.TurHistQuad import *
from .vie.VieQuADRetrieval import *
from .zho.CMTEBRetrieval import *
from .zho.LeCaRDv2Retrieval import *
